@@ -11,7 +11,7 @@
 SpeedScript support in html lexer
 Differentiate between labels and variables
   Option 1: By symbols table
-  Option 2: As a single unidentified symbol in a sytactical line 
+  Option 2: As a single unidentified symbol in a sytactical line
 
 **/
 
@@ -40,9 +40,7 @@ Differentiate between labels and variables
 #include "SparseState.h"
 #include "DefaultLexer.h"
 
-#ifdef SCI_NAMESPACE
 using namespace Scintilla;
-#endif
 
 namespace {
    // Use an unnamed namespace to protect the functions and classes from name conflicts
@@ -76,7 +74,7 @@ namespace {
 
    bool IsStreamCommentStyle(int style) {
       return style == SCE_ABL_COMMENT;
-             // style == SCE_ABL_LINECOMMENT;  Only block comments are used for folding 
+             // style == SCE_ABL_LINECOMMENT;  Only block comments are used for folding
    }
 
    // Options used for LexerABL
@@ -138,6 +136,7 @@ class LexerABL : public DefaultLexer {
    OptionSetABL osABL;
 public:
    LexerABL() :
+      DefaultLexer("abl", SCLEX_PROGRESS),
       setWord(CharacterSet::setAlphaNum, "_", 0x80, true),
       setNegationOp(CharacterSet::setNone, "!"),
       setArithmethicOp(CharacterSet::setNone, "+-/*%"),
@@ -150,7 +149,7 @@ public:
       delete this;
    }
    int SCI_METHOD Version() const override {
-      return lvRelease4;
+      return lvRelease5;
    }
    const char * SCI_METHOD PropertyNames() override {
       return osABL.PropertyNames();
@@ -162,7 +161,10 @@ public:
       return osABL.DescribeProperty(name);
    }
    Sci_Position SCI_METHOD PropertySet(const char *key, const char *val) override ;
-   
+   const char * SCI_METHOD PropertyGet(const char *key) override {
+	   return osABL.PropertyGet(key);
+   }
+
    const char * SCI_METHOD DescribeWordListSets() override {
       return osABL.DescribeWordListSets();
    }
@@ -176,7 +178,7 @@ public:
    int SCI_METHOD LineEndTypesSupported() override {
       return SC_LINE_END_TYPE_DEFAULT;
    }
-   static ILexer4 *LexerFactoryABL() {
+   static ILexer5 *LexerFactoryABL() {
       return new LexerABL();
    }
 };
@@ -238,7 +240,7 @@ void SCI_METHOD LexerABL::Lex(Sci_PositionU startPos, Sci_Position length, int i
             continuationLine = styler.SafeGetCharAt(endLinePrevious-1) == '~';
          }
       }
-   } 
+   }
 
     // Look back to set variables that are actually invisible secondary states. The reason to avoid formal states is to cut down on state's bits
    if (startPos > 0) {
@@ -256,9 +258,9 @@ void SCI_METHOD LexerABL::Lex(Sci_PositionU startPos, Sci_Position length, int i
          ch = styler.SafeGetCharAt(back);
          styler.Flush();  // looking at styles so need to flush
          st = styler.StyleAt(back);
-         
+
          chPrev = styler.SafeGetCharAt(back-1);
-         // isSentenceStart is a non-visible state, used to identify where statements and preprocessor declerations can start 
+         // isSentenceStart is a non-visible state, used to identify where statements and preprocessor declerations can start
          if (checkIsSentenceStart && st != SCE_ABL_COMMENT && st != SCE_ABL_LINECOMMENT && st != SCE_ABL_CHARACTER  && st != SCE_ABL_STRING ) {
             chPrev_1 = styler.SafeGetCharAt(back-2);
             chPrev_2 = styler.SafeGetCharAt(back-3);
@@ -289,7 +291,7 @@ void SCI_METHOD LexerABL::Lex(Sci_PositionU startPos, Sci_Position length, int i
                // eat the '*' so we don't miscount a /* if we see */*/
                --back;
             }
-         }         
+         }
          --back;
       }
    }
