@@ -72,7 +72,7 @@ def nameOKSrc(src):
 		return False
 	if "IFaceTable" in srcPath:
 		return False
-	if "Exporters" in srcPath:
+	if "Export" in srcPath:
 		return False
 	return True
 
@@ -106,7 +106,7 @@ for srcPath in srcPaths:
 			#print parts
 			if len(parts) > 1:
 				propertyName = parts[1]
-				if propertyName:
+				if propertyName and propertyName != "1":
 					propertyNames[propertyName] = 0
 					#print propertyName
 		if '"' in srcLine and nameOKSrc(srcPath):
