@@ -40,7 +40,7 @@ def conversionSets():
     # with complex cases.
     complexes = []
     symmetrics = []
-    for ch in range(sys.maxunicode):
+    for ch in range(sys.maxunicode + 1):
         if ch >= 0xd800 and ch <= 0xDBFF:
             continue
         if ch >= 0xdc00 and ch <= 0xDFFF:
