@@ -30,6 +30,9 @@
 # On Fedora 17, qmake is called qmake-qt4 so sepbuild.py should probe for correct name.
 # There are also problems with clang failing in the g++ 4.7 headers.
 
+# Turn off deprecation warnings if not interested:
+#export CXXFLAGS=-Wno-deprecated-declarations
+
 # Run commands in parallel up to number of processors
 JOBS="-j $(getconf _NPROCESSORS_ONLN)"
 
@@ -43,14 +46,26 @@ make $JOBS test
 make clean
 cd ../../..
 
+cd scintilla/lexilla/src
+make clean
+make $JOBS
+cd ..
+cd test
+make clean
+make test
+make clean
+cd ..
+cd src
+make clean
+cd ../../..
+
 cd scintilla/gtk
 make clean
-make $JOBS CHECK_DEPRECATED=1
+make $JOBS
 cd ../..
 
 cd scite/gtk
 make clean
-# Don't bother with CHECK_DEPRECATED on SciTE as the GTK+ 3.x code path fixes the deprecations
 make $JOBS
 cd ../..
 
@@ -58,12 +73,12 @@ cd ../..
 # Target 2: gcc build for GTK+ 3
 cd scintilla/gtk
 make clean
-make $JOBS GTK3=1 CHECK_DEPRECATED=1
+make $JOBS GTK3=1
 cd ../..
 
 cd scite/gtk
 make clean
-make $JOBS GTK3=1 CHECK_DEPRECATED=1
+make $JOBS GTK3=1
 cd ../..
 
 # ************************************************************
@@ -111,12 +126,11 @@ cd ../..
 # Target 4: clang build for GTK+ 2
 cd scintilla/gtk
 make clean
-make $JOBS CLANG=1 CHECK_DEPRECATED=1
+make $JOBS CLANG=1
 cd ../..
 
 cd scite/gtk
 make clean
-# Don't bother with CHECK_DEPRECATED on SciTE as the GTK+ 3.x code path fixes the deprecations
 make $JOBS CLANG=1
 cd ../..
 
@@ -124,19 +138,19 @@ cd ../..
 # Target 5: clang build for GTK+ 3
 cd scintilla/gtk
 make clean
-make $JOBS CLANG=1 GTK3=1 CHECK_DEPRECATED=1
+make $JOBS CLANG=1 GTK3=1
 cd ../..
 
 cd scite/gtk
 make clean
-make $JOBS CLANG=1 GTK3=1 CHECK_DEPRECATED=1
+make $JOBS CLANG=1 GTK3=1
 cd ../..
 
 # ************************************************************
 # Target 6: clang analyze for GTK+ 2
 cd scintilla/gtk
 make clean
-make $JOBS CHECK_DEPRECATED=1 analyze
+make $JOBS analyze
 cd ../..
 
 cd scite/gtk
