@@ -10,8 +10,7 @@
 
 #include <string>
 #include <vector>
-
-#include "Scintilla.h"
+#include <chrono>
 
 #include "GUI.h"
 
@@ -36,13 +35,13 @@ std::string ExtractLine(const char *buf, size_t length) {
 
 static const char codingCookie[] = "coding";
 
-static bool isEncodingChar(char ch) {
+static bool isEncodingChar(char ch) noexcept {
 	return (ch == '_') || (ch == '-') || (ch == '.') ||
 	       (ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z') ||
 	       (ch >= '0' && ch <= '9');
 }
 
-static bool isSpaceChar(char ch) {
+static bool isSpaceChar(char ch) noexcept {
 	return (ch == ' ') || (ch == '\t');
 }
 
@@ -56,12 +55,12 @@ static UniMode CookieValue(const std::string &s) {
 				posCoding++;
 			}
 			while ((posCoding < s.length()) &&
-			        (isSpaceChar(s[posCoding]))) {
+					(isSpaceChar(s[posCoding]))) {
 				posCoding++;
 			}
 			size_t endCoding = posCoding;
 			while ((endCoding < s.length()) &&
-			        (isEncodingChar(s[endCoding]))) {
+					(isEncodingChar(s[endCoding]))) {
 				endCoding++;
 			}
 			std::string code(s, posCoding, endCoding-posCoding);
