@@ -7,7 +7,6 @@
 
 #include <cstdlib>
 #include <cstring>
-#include <cctype>
 #include <cstdio>
 #include <ctime>
 #include <cerrno>
@@ -16,10 +15,11 @@
 #include <string_view>
 #include <vector>
 #include <algorithm>
+#include <chrono>
 
 #include <fcntl.h>
 
-#if defined(__unix__)
+#if defined(__unix__) || defined(__APPLE__)
 
 #include <unistd.h>
 #include <dirent.h>
@@ -28,7 +28,7 @@
 
 #include <sys/stat.h>
 
-#if !defined(__unix__)
+#if !(defined(__unix__) || defined(__APPLE__))
 
 #include <io.h>
 
@@ -42,14 +42,11 @@
 
 #endif
 
-#include "Scintilla.h"
-
 #include "GUI.h"
-#include "ScintillaWindow.h"
 
 #include "FilePath.h"
 
-#if defined(__unix__)
+#if defined(__unix__) || defined(__APPLE__)
 const GUI::gui_char pathSepString[] = "/";
 const GUI::gui_char pathSepChar = '/';
 const GUI::gui_char listSepString[] = ":";
@@ -71,6 +68,8 @@ const GUI::gui_char currentDirectory[] = GUI_TEXT(".");
 const GUI::gui_char parentDirectory[] = GUI_TEXT("..");
 }
 
+FilePath::FilePath() noexcept = default;
+
 FilePath::FilePath(const GUI::gui_char *fileName_) : fileName(fileName_ ? fileName_ : GUI_TEXT("")) {}
 
 FilePath::FilePath(const GUI::gui_string &fileName_) : fileName(fileName_) {}
@@ -103,32 +102,32 @@ void FilePath::SetDirectory(FilePath const &directory) {
 	Set(directory, curName);
 }
 
-void FilePath::Init() {
+void FilePath::Init() noexcept {
 	fileName.clear();
 }
 
-bool FilePath::operator==(const FilePath &other) const {
+bool FilePath::operator==(const FilePath &other) const noexcept {
 	return SameNameAs(other);
 }
 
-bool FilePath::operator<(const FilePath &other) const {
+bool FilePath::operator<(const FilePath &other) const noexcept {
 	return fileName < other.fileName;
 }
 
-bool FilePath::SameNameAs(const GUI::gui_char *other) const {
+bool FilePath::SameNameAs(const GUI::gui_char *other) const noexcept {
 #ifdef WIN32
 	return CSTR_EQUAL == CompareString(LOCALE_SYSTEM_DEFAULT, NORM_IGNORECASE,
-		fileName.c_str(), -1, other, -1);
+					   fileName.c_str(), -1, other, -1);
 #else
 	return fileName == other;
 #endif
 }
 
-bool FilePath::SameNameAs(const FilePath &other) const {
+bool FilePath::SameNameAs(const FilePath &other) const noexcept {
 	return SameNameAs(other.fileName.c_str());
 }
 
-bool FilePath::IsSet() const {
+bool FilePath::IsSet() const noexcept {
 	return fileName.length() > 0;
 }
 
@@ -140,7 +139,7 @@ bool FilePath::IsUntitled() const {
 bool FilePath::IsAbsolute() const {
 	if (fileName.length() == 0)
 		return false;
-#ifdef __unix__
+#if defined(__unix__) || defined(__APPLE__)
 	if (fileName[0] == '/')
 		return true;
 #endif
@@ -155,14 +154,14 @@ bool FilePath::IsAbsolute() const {
 bool FilePath::IsRoot() const {
 #ifdef WIN32
 	if ((fileName[0] == pathSepChar) && (fileName[1] == pathSepChar) && (fileName.find(pathSepString, 2) == GUI::gui_string::npos))
-        return true; // UNC path like \\server
+		return true; // UNC path like \\server
 	return (fileName.length() == 3) && (fileName[1] == ':') && (fileName[2] == pathSepChar);
 #else
 	return fileName == "/";
 #endif
 }
 
-int FilePath::RootLength() {
+int FilePath::RootLength() noexcept {
 #ifdef WIN32
 	return 3;
 #else
@@ -170,7 +169,7 @@ int FilePath::RootLength() {
 #endif
 }
 
-const GUI::gui_char *FilePath::AsInternal() const {
+const GUI::gui_char *FilePath::AsInternal() const noexcept {
 	return fileName.c_str();
 }
 
@@ -232,36 +231,32 @@ FilePath FilePath::Directory() const {
 // Substitute functions that take wchar_t arguments but have the same name
 // as char functions so that the compiler will choose the right form.
 
-static size_t strlen(const wchar_t *str) {
+static size_t strlen(const wchar_t *str) noexcept {
 	return wcslen(str);
 }
 
-static wchar_t *getcwd(wchar_t *buffer, int maxlen) {
-	return _wgetcwd(buffer, maxlen);
-}
-
-static int chdir(const wchar_t *dirname) {
+static int chdir(const wchar_t *dirname) noexcept {
 	return _wchdir(dirname);
 }
 
-static FILE *fopen(const wchar_t *filename, const wchar_t *mode) {
+static FILE *fopen(const wchar_t *filename, const wchar_t *mode) noexcept {
 	return _wfopen(filename, mode);
 }
 
-static int unlink(const wchar_t *filename) {
+static int unlink(const wchar_t *filename) noexcept {
 	return _wunlink(filename);
 }
 
-static int access(const wchar_t *path, int mode) {
+static int access(const wchar_t *path, int mode) noexcept {
 	return _waccess(path, mode);
 }
 
 #if defined(_MSC_VER) && (_MSC_VER > 1310)
-static int stat(const wchar_t *path, struct _stat64i32 *buffer) {
+static int stat(const wchar_t *path, struct _stat64i32 *buffer) noexcept {
 	return _wstat(path, buffer);
 }
 #else
-static int stat(const wchar_t *path, struct _stat *buffer) {
+static int stat(const wchar_t *path, struct _stat *buffer) noexcept {
 	return _wstat(path, buffer);
 }
 #endif
@@ -338,24 +333,27 @@ FilePath FilePath::AbsolutePath() const {
 #endif
 }
 
-// Only used on Windows to fix the case of file names
-
 FilePath FilePath::GetWorkingDirectory() {
-	GUI::gui_char dir[MAX_PATH + 1];
-	dir[0] = '\0';
-	if (getcwd(dir, MAX_PATH)) {
-		dir[MAX_PATH] = '\0';
+	// Call getcwd with (nullptr, 0) to always allocate
+#ifdef WIN32
+	GUI::gui_char *pdir = _wgetcwd(nullptr, 0);
+#else
+	GUI::gui_char *pdir = getcwd(nullptr, 0);
+#endif
+	if (pdir) {
+		GUI::gui_string gswd(pdir);
+		free(pdir);
 		// In Windows, getcwd returns a trailing backslash
 		// when the CWD is at the root of a disk, so remove it
-		size_t endOfPath = strlen(dir) - 1;
-		if (dir[endOfPath] == pathSepChar) {
-			dir[endOfPath] = '\0';
+		if (!gswd.empty() && (gswd.back() == pathSepChar)) {
+			gswd.pop_back();
 		}
+		return FilePath(gswd);
 	}
-	return FilePath(dir);
+	return FilePath();
 }
 
-bool FilePath::SetWorkingDirectory() const {
+bool FilePath::SetWorkingDirectory() const noexcept {
 	return chdir(AsInternal()) == 0;
 }
 
@@ -369,7 +367,7 @@ void FilePath::List(FilePathSet &directories, FilePathSet &files) const {
 		while (!complete) {
 			const std::wstring_view entryName = findFileData.cFileName;
 			if ((entryName != currentDirectory) && (entryName != parentDirectory)) {
-				FilePath pathFull(AsInternal(), findFileData.cFileName);
+				FilePath pathFull(*this, findFileData.cFileName);
 				if (findFileData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) {
 					directories.push_back(pathFull);
 				} else {
@@ -408,7 +406,7 @@ void FilePath::List(FilePathSet &directories, FilePathSet &files) const {
 	std::sort(directories.begin(), directories.end());
 }
 
-FILE *FilePath::Open(const GUI::gui_char *mode) const {
+FILE *FilePath::Open(const GUI::gui_char *mode) const noexcept {
 	if (IsSet()) {
 		return fopen(fileName.c_str(), mode);
 	} else {
@@ -434,7 +432,7 @@ std::string FilePath::Read() const {
 	return data;
 }
 
-void FilePath::Remove() const {
+void FilePath::Remove() const noexcept {
 	unlink(AsInternal());
 }
 
@@ -463,7 +461,7 @@ time_t FilePath::ModifiedTime() const {
 		return 0;
 }
 
-long long FilePath::GetFileLength() const {
+long long FilePath::GetFileLength() const noexcept {
 #ifdef WIN32
 	// Using Win32 API as stat variants are complex and there were problems with stat
 	// working on XP when compiling with XP compatibility flag.
@@ -482,7 +480,7 @@ long long FilePath::GetFileLength() const {
 #endif
 }
 
-bool FilePath::Exists() const {
+bool FilePath::Exists() const noexcept {
 	bool ret = false;
 	if (IsSet()) {
 		FILE *fp = Open(fileRead);
@@ -494,7 +492,7 @@ bool FilePath::Exists() const {
 	return ret;
 }
 
-bool FilePath::IsDirectory() const {
+bool FilePath::IsDirectory() const noexcept {
 #ifdef _WIN32
 #if defined(_MSC_VER) && (_MSC_VER > 1310)
 	struct _stat64i32 statusFile;
@@ -518,10 +516,11 @@ namespace {
 
 #ifdef _WIN32
 void Lowercase(GUI::gui_string &s) {
-	const int chars = ::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), static_cast<int>(s.size())+1, nullptr, 0);
-	std::vector<wchar_t> vc(chars);
-	::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), static_cast<int>(s.size())+1, &vc[0], chars);
-	s = &vc[0];
+	const int sLength = static_cast<int>(s.length());
+	const int chars = ::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), sLength, nullptr, 0);
+	GUI::gui_string vc(chars, 0);
+	::LCMapString(LOCALE_SYSTEM_DEFAULT, LCMAP_LOWERCASE, s.c_str(), sLength, vc.data(), chars);
+	s = vc;
 }
 #endif
 
@@ -586,7 +585,7 @@ bool FilePath::Matches(const GUI::gui_char *pattern) const {
  * @returns true on success, and the long path in @a longPath,
  * false on failure.
  */
-static bool MakeLongPath(const GUI::gui_char* shortPath, GUI::gui_string &longPath) {
+static bool MakeLongPath(const GUI::gui_char *shortPath, GUI::gui_string &longPath) {
 	if (!*shortPath) {
 		return false;
 	}
@@ -645,7 +644,7 @@ void FilePath::FixName() {
 #endif
 }
 
-bool FilePath::CaseSensitive() {
+bool FilePath::CaseSensitive() noexcept {
 #if defined (__APPLE__)
 	return false;
 #elif defined(__unix__)
@@ -682,27 +681,26 @@ std::string CommandExecute(const GUI::gui_char *command, const GUI::gui_char *di
 
 	// Make child process use hPipeWrite as standard out, and make
 	// sure it does not show on screen.
-	STARTUPINFOW si = {
-			     sizeof(STARTUPINFO), nullptr, nullptr, nullptr, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, nullptr, 0, 0, 0
-			 };
+	STARTUPINFOW si = {};
+	si.cb = sizeof(STARTUPINFO);
 	si.dwFlags = STARTF_USESHOWWINDOW | STARTF_USESTDHANDLES;
 	si.wShowWindow = SW_HIDE;
 	si.hStdInput = hRead2;
 	si.hStdOutput = hPipeWrite;
 	si.hStdError = hPipeWrite;
 
-	PROCESS_INFORMATION pi = {0, 0, 0, 0};
+	PROCESS_INFORMATION pi = {};
 
 	std::vector<wchar_t> vwcCommand(command, command + wcslen(command) + 1);
 
 	const BOOL running = ::CreateProcessW(
-			  nullptr,
-			  &vwcCommand[0],
-			  nullptr, nullptr,
-			  TRUE, CREATE_NEW_PROCESS_GROUP,
-			  nullptr,
-			  (directoryForRun && directoryForRun[0]) ? directoryForRun : nullptr,
-			  &si, &pi);
+				     nullptr,
+				     &vwcCommand[0],
+				     nullptr, nullptr,
+				     TRUE, CREATE_NEW_PROCESS_GROUP,
+				     nullptr,
+				     (directoryForRun && directoryForRun[0]) ? directoryForRun : nullptr,
+				     &si, &pi);
 
 	if (running && pi.hProcess && pi.hThread) {
 		// Wait until child process exits but time out after 5 seconds.
@@ -712,13 +710,13 @@ std::string CommandExecute(const GUI::gui_char *command, const GUI::gui_char *di
 		DWORD bytesAvail = 0;
 		char buffer[8 * 1024];
 
-		if (::PeekNamedPipe(hPipeRead, buffer, sizeof(buffer), &bytesRead, &bytesAvail, NULL)) {
+		if (::PeekNamedPipe(hPipeRead, buffer, sizeof(buffer), &bytesRead, &bytesAvail, nullptr)) {
 			if (bytesAvail > 0) {
 				int bTest = ::ReadFile(hPipeRead, buffer, sizeof(buffer), &bytesRead, nullptr);
 				while (bTest && bytesRead) {
 					output.append(buffer, buffer+bytesRead);
 					bytesRead = 0;
-					if (::PeekNamedPipe(hPipeRead, buffer, sizeof(buffer), &bytesRead, &bytesAvail, NULL)) {
+					if (::PeekNamedPipe(hPipeRead, buffer, sizeof(buffer), &bytesRead, &bytesAvail, nullptr)) {
 						if (bytesAvail) {
 							bTest = ::ReadFile(hPipeRead, buffer, sizeof(buffer), &bytesRead, nullptr);
 						}
