@@ -12,15 +12,6 @@ extern const GUI::gui_char configFileVisibilityString[];
 extern const GUI::gui_char fileRead[];
 extern const GUI::gui_char fileWrite[];
 
-#if defined(__unix__)
-#include <climits>
-#ifdef PATH_MAX
-#define MAX_PATH PATH_MAX
-#else
-#define MAX_PATH 260
-#endif
-#endif
-
 class FilePath;
 
 typedef std::vector<FilePath> FilePathSet;
@@ -28,29 +19,31 @@ typedef std::vector<FilePath> FilePathSet;
 class FilePath {
 	GUI::gui_string fileName;
 public:
-	FilePath(const GUI::gui_char *fileName_ = GUI_TEXT(""));
+	FilePath() noexcept;
+	FilePath(const GUI::gui_char *fileName_);
 	FilePath(const GUI::gui_string &fileName_);
 	FilePath(FilePath const &directory, FilePath const &name);
 	FilePath(FilePath const &) = default;
-	FilePath(FilePath &&) = default;
+	FilePath(FilePath &&) noexcept = default;
 	FilePath &operator=(FilePath const &) = default;
-	FilePath &operator=(FilePath &&) = default;
+	FilePath &operator=(FilePath &&) noexcept = default;
 	virtual ~FilePath() = default;
+
 	void Set(const GUI::gui_char *fileName_);
 	void Set(FilePath const &other);
 	void Set(FilePath const &directory, FilePath const &name);
 	void SetDirectory(FilePath const &directory);
-	virtual void Init();
-	bool SameNameAs(const GUI::gui_char *other) const;
-	bool SameNameAs(const FilePath &other) const;
-	bool operator==(const FilePath &other) const;
-	bool operator<(const FilePath &other) const;
-	bool IsSet() const;
+	virtual void Init() noexcept;
+	bool SameNameAs(const GUI::gui_char *other) const noexcept;
+	bool SameNameAs(const FilePath &other) const noexcept;
+	bool operator==(const FilePath &other) const noexcept;
+	bool operator<(const FilePath &other) const noexcept;
+	bool IsSet() const noexcept;
 	bool IsUntitled() const;
 	bool IsAbsolute() const;
 	bool IsRoot() const;
-	static int RootLength();
-	const GUI::gui_char *AsInternal() const;
+	static int RootLength() noexcept;
+	const GUI::gui_char *AsInternal() const noexcept;
 	std::string AsUTF8() const;
 	FilePath Name() const;
 	FilePath BaseName() const;
@@ -60,17 +53,17 @@ public:
 	FilePath AbsolutePath() const;
 	FilePath NormalizePath() const;
 	static FilePath GetWorkingDirectory();
-	bool SetWorkingDirectory() const;
+	bool SetWorkingDirectory() const noexcept;
 	void List(FilePathSet &directories, FilePathSet &files) const;
-	FILE *Open(const GUI::gui_char *mode) const;
+	FILE *Open(const GUI::gui_char *mode) const noexcept;
 	std::string Read() const;
-	void Remove() const;
+	void Remove() const noexcept;
 	time_t ModifiedTime() const;
-	long long GetFileLength() const;
-	bool Exists() const;
-	bool IsDirectory() const;
+	long long GetFileLength() const noexcept;
+	bool Exists() const noexcept;
+	bool IsDirectory() const noexcept;
 	bool Matches(const GUI::gui_char *pattern) const;
-	static bool CaseSensitive();
+	static bool CaseSensitive() noexcept;
 };
 
 std::string CommandExecute(const GUI::gui_char *command, const GUI::gui_char *directoryForRun);
