@@ -32,13 +32,13 @@ public:
 	bool OnExecute(const char *s) override;
 	bool OnSavePointReached() override;
 	bool OnSavePointLeft() override;
-	bool OnStyle(unsigned int startPos, int lengthDoc, int initStyle, StyleWriter *styler) override;
+	bool OnStyle(Scintilla::API::Position startPos, Scintilla::API::Position lengthDoc, int initStyle, StyleWriter *styler) override;
 	bool OnDoubleClick() override;
 	bool OnUpdateUI() override;
 	bool OnMarginClick() override;
 	bool OnUserListSelection(int listType, const char *selection) override;
 	bool OnKey(int keyval, int modifiers) override;
-	bool OnDwellStart(int pos, const char *word) override;
+	bool OnDwellStart(Scintilla::API::Position pos, const char *word) override;
 	bool OnClose(const char *filename) override;
 	bool OnUserStrip(int control, int change) override;
 	bool NeedsOnClose() override;
