@@ -9,7 +9,6 @@
 #include <cstdlib>
 #include <cassert>
 #include <cstring>
-#include <cctype>
 #include <cstdio>
 #include <cmath>
 
@@ -27,6 +26,7 @@
 #include "ILexer.h"
 #include "Scintilla.h"
 
+#include "CharacterCategory.h"
 #include "Position.h"
 #include "IntegerRectangle.h"
 #include "UniqueString.h"
@@ -101,7 +101,7 @@ void DrawWrapMarker(Surface *surface, PRectangle rcPlace,
 		y - 2 * dy);
 }
 
-MarginView::MarginView() {
+MarginView::MarginView() noexcept {
 	wrapMarkerPaddingRight = 3;
 	customDrawWrapMarker = nullptr;
 }
@@ -420,7 +420,7 @@ void MarginView::PaintMargin(Surface *surface, Sci::Line topLine, PRectangle rc,
 							DrawStyledText(surface, vs, vs.marginStyleOffset, rcMarker,
 								stMargin, 0, stMargin.length, drawAll);
 						} else {
-							// if we're displaying annotation lines, color the margin to match the associated document line
+							// if we're displaying annotation lines, colour the margin to match the associated document line
 							const int annotationLines = model.pdoc->AnnotationLines(lineDoc);
 							if (annotationLines && (visibleLine > lastVisibleLine - annotationLines)) {
 								surface->FillRectangle(rcMarker, vs.styles[stMargin.StyleAt(0) + vs.marginStyleOffset].back);
