@@ -60,7 +60,7 @@ bool Buffer::NeedsSave(int delayBeforeSave) const {
 }
 
 void Buffer::CompleteLoading() noexcept {
-	lifeState = open;
+	lifeState = opened;
 	if (pFileWorker && pFileWorker->IsLoading()) {
 		delete pFileWorker;
 		pFileWorker = nullptr;
@@ -878,7 +878,7 @@ void SciTEBase::New() {
 	SetBuffersMenu();
 	CurrentBuffer()->isDirty = false;
 	CurrentBuffer()->failedSave = false;
-	CurrentBuffer()->lifeState = Buffer::open;
+	CurrentBuffer()->lifeState = Buffer::opened;
 	jobQueue.isBuilding = false;
 	jobQueue.isBuilt = false;
 	CurrentBuffer()->isReadOnly = false;	// No sense to create an empty, read-only buffer...
@@ -940,7 +940,7 @@ void SciTEBase::Close(bool updateUI, bool loadingSession, bool makingRoomForNew)
 		closingLast = (buffers.lengthVisible == 1) && !buffers.buffers[0].pFileWorker;
 		if (closingLast) {
 			buffers.buffers[0].Init();
-			buffers.buffers[0].lifeState = Buffer::open;
+			buffers.buffers[0].lifeState = Buffer::opened;
 			if (extender)
 				extender->InitBuffer(0);
 		} else {
@@ -1256,7 +1256,7 @@ bool SciTEBase::AddFileToBuffer(const BufferState &bufferState) {
 				buffers.buffers[iBuffer].file.selection = bufferState.file.selection;
 				buffers.buffers[iBuffer].foldState = bufferState.foldState;
 				buffers.buffers[iBuffer].bookmarks = bufferState.bookmarks;
-				if (buffers.buffers[iBuffer].lifeState == Buffer::open) {
+				if (buffers.buffers[iBuffer].lifeState == Buffer::opened) {
 					// File was opened synchronously
 					RestoreState(buffers.buffers[iBuffer], true);
 					DisplayAround(buffers.buffers[iBuffer].file);
@@ -1872,6 +1872,20 @@ static void Chomp(std::string &s, char ch) {
 		s.erase(0, posCh + 1);
 }
 
+namespace {
+
+char Severity(const std::string &message) noexcept {
+	if (message.find("fatal") != std::string::npos)
+		return 3;
+	if (message.find("error") != std::string::npos)
+		return 2;
+	if (message.find("warning") != std::string::npos)
+		return 1;
+	return 0;
+}
+
+}
+
 void SciTEBase::ShowMessages(SA::Line line) {
 	wEditor.AnnotationSetStyleOffset(diagnosticStyleStart);
 	wEditor.AnnotationSetVisible(SA::AnnotationVisible::Boxed);
@@ -1910,25 +1924,16 @@ void SciTEBase::ShowMessages(SA::Line line) {
 					}
 				}
 			}
-			const int lenCurrent = wEditor.AnnotationGetText(sourceLine, nullptr);
-			std::string msgCurrent(lenCurrent, '\0');
-			std::string stylesCurrent(lenCurrent, '\0');
-			if (lenCurrent) {
-				wEditor.AnnotationGetText(sourceLine, &msgCurrent[0]);
-				wEditor.AnnotationGetStyles(sourceLine, &stylesCurrent[0]);
-				msgCurrent += "\n";
-				stylesCurrent += '\0';
-			}
-			if (msgCurrent.find(message.c_str()) == std::string::npos) {
+			std::string msgCurrent = wEditor.AnnotationGetText(sourceLine);
+			if (msgCurrent.find(message) == std::string::npos) {
 				// Only append unique messages
-				msgCurrent += message.c_str();
-				char msgStyle = 0;
-				if (message.find("warning") != std::string::npos)
-					msgStyle = 1;
-				if (message.find("error") != std::string::npos)
-					msgStyle = 2;
-				if (message.find("fatal") != std::string::npos)
-					msgStyle = 3;
+				std::string stylesCurrent = wEditor.AnnotationGetStyles(sourceLine);
+				if (msgCurrent.length()) {
+					msgCurrent += "\n";
+					stylesCurrent += '\0';
+				}
+				msgCurrent += message;
+				const char msgStyle = Severity(message);
 				stylesCurrent += std::string(message.length(), msgStyle);
 				wEditor.AnnotationSetText(sourceLine, msgCurrent.c_str());
 				wEditor.AnnotationSetStyles(sourceLine, stylesCurrent.c_str());
