@@ -11,35 +11,35 @@
 // Read only access to a document, its styles and other data
 class TextReader {
 protected:
-	enum {extremePosition=0x7FFFFFFF};
+	const Scintilla::API::Position extremePosition = INTPTR_MAX;
 	/** @a bufferSize is a trade off between time taken to copy the characters
 	 * and retrieval overhead.
 	 * @a slopSize positions the buffer before the desired position
 	 * in case there is some backtracking. */
 	enum {bufferSize=4000, slopSize=bufferSize/8};
 	char buf[bufferSize+1];
-	int startPos;
-	int endPos;
+	Scintilla::API::Position startPos;
+	Scintilla::API::Position endPos;
 	int codePage;
 
-	GUI::ScintillaWindow &sw;
-	int lenDoc;
+	Scintilla::API::ScintillaCall &sc;
+	Scintilla::API::Position lenDoc;
 
 	bool InternalIsLeadByte(char ch) const;
-	void Fill(int position);
+	void Fill(Scintilla::API::Position position);
 public:
-	explicit TextReader(GUI::ScintillaWindow &sw_);
+	explicit TextReader(Scintilla::API::ScintillaCall &sc_) noexcept;
 	// Deleted so TextReader objects can not be copied.
 	TextReader(const TextReader &source) = delete;
 	TextReader &operator=(const TextReader &) = delete;
-	char operator[](int position) {
+	char operator[](Scintilla::API::Position position) {
 		if (position < startPos || position >= endPos) {
 			Fill(position);
 		}
 		return buf[position - startPos];
 	}
 	/** Safe version of operator[], returning a defined value for invalid position. */
-	char SafeGetCharAt(int position, char chDefault=' ') {
+	char SafeGetCharAt(Scintilla::API::Position position, char chDefault=' ') {
 		if (position < startPos || position >= endPos) {
 			Fill(position);
 			if (position < startPos || position >= endPos) {
@@ -52,37 +52,37 @@ public:
 	bool IsLeadByte(char ch) const {
 		return codePage && InternalIsLeadByte(ch);
 	}
-	void SetCodePage(int codePage_) {
+	void SetCodePage(int codePage_) noexcept {
 		codePage = codePage_;
 	}
-	bool Match(int pos, const char *s);
-	int StyleAt(int position);
-	int GetLine(int position);
-	int LineStart(int line);
-	int LevelAt(int line);
-	int Length();
-	int GetLineState(int line);
+	bool Match(Scintilla::API::Position pos, const char *s);
+	int StyleAt(Scintilla::API::Position position);
+	Scintilla::API::Line GetLine(Scintilla::API::Position position);
+	Scintilla::API::Position LineStart(Scintilla::API::Line line);
+	Scintilla::API::FoldLevel LevelAt(Scintilla::API::Line line);
+	Scintilla::API::Position Length();
+	int GetLineState(Scintilla::API::Line line);
 };
 
 // Adds methods needed to write styles and folding
 class StyleWriter : public TextReader {
 protected:
 	char styleBuf[bufferSize];
-	int validLen;
-	unsigned int startSeg;
+	Scintilla::API::Position validLen;
+	Scintilla::API::Position startSeg;
 public:
-	explicit StyleWriter(GUI::ScintillaWindow &sw_);
+	explicit StyleWriter(Scintilla::API::ScintillaCall &sc_) noexcept;
 	// Deleted so StyleWriter objects can not be copied.
 	StyleWriter(const StyleWriter &source) = delete;
 	StyleWriter &operator=(const StyleWriter &) = delete;
 	void Flush();
-	int SetLineState(int line, int state);
+	void SetLineState(Scintilla::API::Line line, int state);
 
-	void StartAt(unsigned int start, char chMask=31);
-	unsigned int GetStartSegment() const { return startSeg; }
-	void StartSegment(unsigned int pos);
-	void ColourTo(unsigned int pos, int chAttr);
-	void SetLevel(int line, int level);
+	void StartAt(Scintilla::API::Position start, char chMask=31);
+	Scintilla::API::Position GetStartSegment() const noexcept { return startSeg; }
+	void StartSegment(Scintilla::API::Position pos) noexcept;
+	void ColourTo(Scintilla::API::Position pos, int chAttr);
+	void SetLevel(Scintilla::API::Line line, Scintilla::API::FoldLevel level);
 };
 
 #endif
