@@ -5,50 +5,75 @@
 // Copyright 1998-2003 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 
 #include <stdexcept>
+#include <string_view>
 #include <vector>
 #include <map>
+#include <algorithm>
+#include <iterator>
+#include <memory>
 
 #include "Platform.h"
 
 #include "XPM.h"
 
-#ifdef SCI_NAMESPACE
 using namespace Scintilla;
-#endif
 
-static const char *NextField(const char *s) {
+namespace {
+
+const char *NextField(const char *s) {
 	// In case there are leading spaces in the string
-	while (*s && *s == ' ') {
+	while (*s == ' ') {
 		s++;
 	}
 	while (*s && *s != ' ') {
 		s++;
 	}
-	while (*s && *s == ' ') {
+	while (*s == ' ') {
 		s++;
 	}
 	return s;
 }
 
 // Data lines in XPM can be terminated either with NUL or "
-static size_t MeasureLength(const char *s) {
+size_t MeasureLength(const char *s) {
 	size_t i = 0;
 	while (s[i] && (s[i] != '\"'))
 		i++;
 	return i;
 }
 
+unsigned int ValueOfHex(const char ch) noexcept {
+	if (ch >= '0' && ch <= '9')
+		return ch - '0';
+	else if (ch >= 'A' && ch <= 'F')
+		return ch - 'A' + 10;
+	else if (ch >= 'a' && ch <= 'f')
+		return ch - 'a' + 10;
+	else
+		return 0;
+}
+
+ColourDesired ColourFromHex(const char *val) noexcept {
+	const unsigned int r = ValueOfHex(val[0]) * 16 + ValueOfHex(val[1]);
+	const unsigned int g = ValueOfHex(val[2]) * 16 + ValueOfHex(val[3]);
+	const unsigned int b = ValueOfHex(val[4]) * 16 + ValueOfHex(val[5]);
+	return ColourDesired(r, g, b);
+}
+
+}
+
+
 ColourDesired XPM::ColourFromCode(int ch) const {
 	return colourCodeTable[ch];
 }
 
-void XPM::FillRun(Surface *surface, int code, int startX, int y, int x) {
+void XPM::FillRun(Surface *surface, int code, int startX, int y, int x) const {
 	if ((code != codeTransparent) && (startX != x)) {
-		PRectangle rc = PRectangle::FromInts(startX, y, x, y + 1);
+		const PRectangle rc = PRectangle::FromInts(startX, y, x, y + 1);
 		surface->FillRectangle(rc, ColourFromCode(code));
 	}
 }
@@ -88,7 +113,7 @@ void XPM::Init(const char *const *linesForm) {
 	if (!linesForm)
 		return;
 
-	std::fill(colourCodeTable, colourCodeTable+256, 0);
+	std::fill(colourCodeTable, std::end(colourCodeTable), ColourDesired(0));
 	const char *line0 = linesForm[0];
 	width = atoi(line0);
 	line0 = NextField(line0);
@@ -104,37 +129,37 @@ void XPM::Init(const char *const *linesForm) {
 
 	for (int c=0; c<nColours; c++) {
 		const char *colourDef = linesForm[c+1];
-		int code = static_cast<unsigned char>(colourDef[0]);
+		const char code = colourDef[0];
 		colourDef += 4;
 		ColourDesired colour(0xff, 0xff, 0xff);
 		if (*colourDef == '#') {
-			colour.Set(colourDef);
+			colour = ColourFromHex(colourDef+1);
 		} else {
-			codeTransparent = static_cast<char>(code);
+			codeTransparent = code;
 		}
-		colourCodeTable[code] = colour;
+		colourCodeTable[static_cast<unsigned char>(code)] = colour;
 	}
 
 	for (int y=0; y<height; y++) {
 		const char *lform = linesForm[y+nColours+1];
-		size_t len = MeasureLength(lform);
+		const size_t len = MeasureLength(lform);
 		for (size_t x = 0; x<len; x++)
-			pixels[y * width + x] = static_cast<unsigned char>(lform[x]);
+			pixels[y * width + x] = lform[x];
 	}
 }
 
-void XPM::Draw(Surface *surface, PRectangle &rc) {
+void XPM::Draw(Surface *surface, const PRectangle &rc) {
 	if (pixels.empty()) {
 		return;
 	}
 	// Centre the pixmap
-	int startY = static_cast<int>(rc.top + (rc.Height() - height) / 2);
-	int startX = static_cast<int>(rc.left + (rc.Width() - width) / 2);
+	const int startY = static_cast<int>(rc.top + (rc.Height() - height) / 2);
+	const int startX = static_cast<int>(rc.left + (rc.Width() - width) / 2);
 	for (int y=0; y<height; y++) {
 		int prevCode = 0;
 		int xStartRun = 0;
 		for (int x=0; x<width; x++) {
-			int code = pixels[y * width + x];
+			const int code = pixels[y * width + x];
 			if (code != prevCode) {
 				FillRun(surface, prevCode, startX + xStartRun, startY + y, startX + x);
 				xStartRun = x;
@@ -147,16 +172,16 @@ void XPM::Draw(Surface *surface, PRectangle &rc) {
 
 void XPM::PixelAt(int x, int y, ColourDesired &colour, bool &transparent) const {
 	if (pixels.empty() || (x<0) || (x >= width) || (y<0) || (y >= height)) {
-		colour = 0;
+		colour = ColourDesired(0);
 		transparent = true;
 		return;
 	}
-	int code = pixels[y * width + x];
+	const int code = pixels[y * width + x];
 	transparent = code == codeTransparent;
 	if (transparent) {
-		colour = 0;
+		colour = ColourDesired(0);
 	} else {
-		colour = ColourFromCode(code).AsLong();
+		colour = ColourFromCode(code);
 	}
 }
 
@@ -169,7 +194,7 @@ std::vector<const char *> XPM::LinesFormFromTextForm(const char *textForm) {
 	for (; countQuotes < (2*strings) && textForm[j] != '\0'; j++) {
 		if (textForm[j] == '\"') {
 			if (countQuotes == 0) {
-				// First field: width, height, number of colors, chars per pixel
+				// First field: width, height, number of colours, chars per pixel
 				const char *line0 = textForm + j + 1;
 				// Skip width
 				line0 = NextField(line0);
@@ -180,7 +205,7 @@ std::vector<const char *> XPM::LinesFormFromTextForm(const char *textForm) {
 				strings += atoi(line0);
 			}
 			if (countQuotes / 2 >= strings) {
-				break;	// Bad height or number of colors!
+				break;	// Bad height or number of colours!
 			}
 			if ((countQuotes & 1) == 0) {
 				linesForm.push_back(textForm + j + 1);
@@ -189,7 +214,7 @@ std::vector<const char *> XPM::LinesFormFromTextForm(const char *textForm) {
 		}
 	}
 	if (textForm[j] == '\0' || countQuotes / 2 > strings) {
-		// Malformed XPM! Height + number of colors too high or too low
+		// Malformed XPM! Height + number of colours too high or too low
 		linesForm.clear();
 	}
 	return linesForm;
@@ -233,9 +258,9 @@ const unsigned char *RGBAImage::Pixels() const {
 void RGBAImage::SetPixel(int x, int y, ColourDesired colour, int alpha) {
 	unsigned char *pixel = &pixelBytes[0] + (y*width+x) * 4;
 	// RGBA
-	pixel[0] = static_cast<unsigned char>(colour.GetRed());
-	pixel[1] = static_cast<unsigned char>(colour.GetGreen());
-	pixel[2] = static_cast<unsigned char>(colour.GetBlue());
+	pixel[0] = colour.GetRed();
+	pixel[1] = colour.GetGreen();
+	pixel[2] = colour.GetBlue();
 	pixel[3] = static_cast<unsigned char>(alpha);
 }
 
@@ -248,10 +273,6 @@ RGBAImageSet::~RGBAImageSet() {
 
 /// Remove all images.
 void RGBAImageSet::Clear() {
-	for (ImageMap::iterator it=images.begin(); it != images.end(); ++it) {
-		delete it->second;
-		it->second = 0;
-	}
 	images.clear();
 	height = -1;
 	width = -1;
@@ -261,10 +282,9 @@ void RGBAImageSet::Clear() {
 void RGBAImageSet::Add(int ident, RGBAImage *image) {
 	ImageMap::iterator it=images.find(ident);
 	if (it == images.end()) {
-		images[ident] = image;
+		images[ident] = std::unique_ptr<RGBAImage>(image);
 	} else {
-		delete it->second;
-		it->second = image;
+		it->second.reset(image);
 	}
 	height = -1;
 	width = -1;
@@ -274,17 +294,17 @@ void RGBAImageSet::Add(int ident, RGBAImage *image) {
 RGBAImage *RGBAImageSet::Get(int ident) {
 	ImageMap::iterator it = images.find(ident);
 	if (it != images.end()) {
-		return it->second;
+		return it->second.get();
 	}
-	return NULL;
+	return nullptr;
 }
 
 /// Give the largest height of the set.
 int RGBAImageSet::GetHeight() const {
 	if (height < 0) {
-		for (ImageMap::const_iterator it=images.begin(); it != images.end(); ++it) {
-			if (height < it->second->GetHeight()) {
-				height = it->second->GetHeight();
+		for (const std::pair<const int, std::unique_ptr<RGBAImage>> &image : images) {
+			if (height < image.second->GetHeight()) {
+				height = image.second->GetHeight();
 			}
 		}
 	}
@@ -294,9 +314,9 @@ int RGBAImageSet::GetHeight() const {
 /// Give the largest width of the set.
 int RGBAImageSet::GetWidth() const {
 	if (width < 0) {
-		for (ImageMap::const_iterator it=images.begin(); it != images.end(); ++it) {
-			if (width < it->second->GetWidth()) {
-				width = it->second->GetWidth();
+		for (const std::pair<const int, std::unique_ptr<RGBAImage>> &image : images) {
+			if (width < image.second->GetWidth()) {
+				width = image.second->GetWidth();
 			}
 		}
 	}
