@@ -10,10 +10,12 @@
 #include <time.h>
 
 #include <string>
+#include <string_view>
 #include <vector>
 #include <map>
 #include <set>
 #include <memory>
+#include <chrono>
 
 #undef _WIN32_WINNT
 #define _WIN32_WINNT  0x0602
@@ -21,7 +23,9 @@
 #include <commctrl.h>
 
 #include "ILexer.h"
-#include "Scintilla.h"
+
+#include "ScintillaTypes.h"
+#include "ScintillaCall.h"
 
 #include "GUI.h"
 #include "ScintillaWindow.h"
@@ -47,8 +51,8 @@ static bool startedByDirector = false;
 static bool shuttingDown = false;
 unsigned int SDI = 0;
 
-static bool HasConnection() {
-	return (wDirector != 0) || (wCorrespondent != 0);
+static bool HasConnection() noexcept {
+	return wDirector || wCorrespondent;
 }
 
 static void SendDirector(const char *verb, const char *arg = nullptr) {
@@ -70,22 +74,22 @@ static void SendDirector(const char *verb, const char *arg = nullptr) {
 		std::string slashedMessage = Slash(addressedMessage, false);
 		COPYDATASTRUCT cds;
 		cds.dwData = 0;
-		cds.cbData = static_cast<int>(slashedMessage.length());
+		cds.cbData = static_cast<DWORD>(slashedMessage.length());
 		slashedMessage.append(1, '\0');	// Ensure NUL at end of string
 		cds.lpData = &slashedMessage[0];
 		::SendMessage(wDestination, WM_COPYDATA,
-			            reinterpret_cast<WPARAM>(wReceiver),
-			            reinterpret_cast<LPARAM>(&cds));
+			      reinterpret_cast<WPARAM>(wReceiver),
+			      reinterpret_cast<LPARAM>(&cds));
 	}
 }
 
-static void SendDirector(const char *verb, sptr_t arg) {
-	std::string s = StdStringFromSizeT(static_cast<size_t>(arg));
+static void SendDirector(const char *verb, intptr_t arg) {
+	std::string s = std::to_string(arg);
 	::SendDirector(verb, s.c_str());
 }
 
-static HWND HwndFromString(const char *s) {
-	return reinterpret_cast<HWND>(static_cast<uptr_t>(atoi(s)));
+static HWND HwndFromString(const char *s) noexcept {
+	return reinterpret_cast<HWND>(static_cast<uintptr_t>(atoll(s)));
 }
 
 static void CheckEnvironment(ExtensionAPI *phost) {
@@ -96,7 +100,7 @@ static void CheckEnvironment(ExtensionAPI *phost) {
 				startedByDirector = true;
 				wDirector = HwndFromString(director.c_str());
 				// Director is just seen so identify this to it
-				::SendDirector("identity", reinterpret_cast<sptr_t>(wReceiver));
+				::SendDirector("identity", reinterpret_cast<intptr_t>(wReceiver));
 			}
 		}
 		std::string sReceiver = StdStringFromSizeT(reinterpret_cast<size_t>(wReceiver));
@@ -117,7 +121,7 @@ static LRESULT HandleCopyData(LPARAM lParam) {
 }
 
 LRESULT PASCAL DirectorExtension_WndProc(
-    HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM lParam) {
+	HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM lParam) {
 	if (iMessage == WM_COPYDATA) {
 		return HandleCopyData(lParam);
 	} else if (iMessage == SDI) {
@@ -126,16 +130,16 @@ LRESULT PASCAL DirectorExtension_WndProc(
 	return ::DefWindowProc(hWnd, iMessage, wParam, lParam);
 }
 
-static void DirectorExtension_Register(HINSTANCE hInstance) {
+static void DirectorExtension_Register(HINSTANCE hInstance) noexcept {
 	WNDCLASS wndclass;
 	wndclass.style = 0;
 	wndclass.lpfnWndProc = DirectorExtension_WndProc;
 	wndclass.cbClsExtra = 0;
 	wndclass.cbWndExtra = 0;
 	wndclass.hInstance = hInstance;
-	wndclass.hIcon = 0;
-	wndclass.hCursor = NULL;
-	wndclass.hbrBackground = NULL;
+	wndclass.hIcon = {};
+	wndclass.hCursor = {};
+	wndclass.hbrBackground = {};
 	wndclass.lpszMenuName = nullptr;
 	wndclass.lpszClassName = DirectorExtension_ClassName;
 	if (!::RegisterClass(&wndclass))
@@ -151,22 +155,22 @@ bool DirectorExtension::Initialise(ExtensionAPI *host_) {
 	host = host_;
 	SDI = ::RegisterWindowMessage(TEXT("SciTEDirectorInterface"));
 	HINSTANCE hInstance = reinterpret_cast<HINSTANCE>(
-	                          host->GetInstance());
+				      host->GetInstance());
 	DirectorExtension_Register(hInstance);
 	wReceiver = ::CreateWindow(
-	                DirectorExtension_ClassName,
-	                DirectorExtension_ClassName,
-	                0,
-	                0, 0, 0, 0,
-	                0,
-	                0,
-	                hInstance,
-	                0);
+			    DirectorExtension_ClassName,
+			    DirectorExtension_ClassName,
+			    0,
+			    0, 0, 0, 0,
+			    0,
+			    0,
+			    hInstance,
+			    nullptr);
 	if (!wReceiver)
 		::exit(FALSE);
 	// Make the frame window handle available so the director can activate it.
 	::SetWindowLongPtr(wReceiver, GWLP_USERDATA,
-		reinterpret_cast<LONG_PTR>((static_cast<SciTEBase*>(host))->GetID()));
+			   reinterpret_cast<LONG_PTR>((static_cast<SciTEBase *>(host))->GetID()));
 	CheckEnvironment(host);
 	return true;
 }
@@ -175,7 +179,7 @@ bool DirectorExtension::Finalise() {
 	::SendDirector("closing");
 	if (wReceiver)
 		::DestroyWindow(wReceiver);
-	wReceiver = 0;
+	wReceiver = {};
 	return true;
 }
 
@@ -242,7 +246,7 @@ bool DirectorExtension::OnSavePointLeft() {
 	return false;
 }
 
-bool DirectorExtension::OnStyle(unsigned int, int, int, StyleWriter *) {
+bool DirectorExtension::OnStyle(SA::Position, SA::Position, int, StyleWriter *) {
 	return false;
 }
 
@@ -296,7 +300,7 @@ void DirectorExtension::HandleStringMessage(const char *message) {
 			if (arg)
 				wDirector = HwndFromString(arg + 1);
 		} else if (isprefix(cmd, "closing:")) {
-			wDirector = 0;
+			wDirector = {};
 			if (startedByDirector) {
 				shuttingDown = true;
 				if (host) {
@@ -307,6 +311,6 @@ void DirectorExtension::HandleStringMessage(const char *message) {
 		} else if (host) {
 			host->Perform(cmd);
 		}
-		wCorrespondent = 0;
+		wCorrespondent = {};
 	}
 }
