@@ -11,14 +11,14 @@
  * Set up properties for FileTime, FileDate, CurrentTime, CurrentDate and FileAttr.
  */
 void SciTEWin::SetFileProperties(
-    PropSetFile &ps) {			///< Property set to update.
+	PropSetFile &ps) {			///< Property set to update.
 
 	const int TEMP_LEN = 100;
-	char temp[TEMP_LEN];
-	HANDLE hf = ::CreateFileW(filePath.AsInternal(), GENERIC_READ, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
+	char temp[TEMP_LEN] = "";
+	HANDLE hf = ::CreateFileW(filePath.AsInternal(), GENERIC_READ, 0, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
 	if (hf != INVALID_HANDLE_VALUE) {
 		FILETIME ft = FILETIME();
-		::GetFileTime(hf, NULL, NULL, &ft);
+		::GetFileTime(hf, nullptr, nullptr, &ft);
 		::CloseHandle(hf);
 		FILETIME lft = FILETIME();
 		::FileTimeToLocalFileTime(&ft, &lft);
@@ -26,13 +26,13 @@ void SciTEWin::SetFileProperties(
 		if (::FileTimeToSystemTime(&lft, &st) == 0)
 			st = SYSTEMTIME();
 		::GetTimeFormatA(LOCALE_USER_DEFAULT,
-		                0, &st,
-		                NULL, temp, TEMP_LEN);
+				 0, &st,
+				 nullptr, temp, TEMP_LEN);
 		ps.Set("FileTime", temp);
 
 		::GetDateFormatA(LOCALE_USER_DEFAULT,
-		                DATE_SHORTDATE, &st,
-		                NULL, temp, TEMP_LEN);
+				 DATE_SHORTDATE, &st,
+				 nullptr, temp, TEMP_LEN);
 		ps.Set("FileDate", temp);
 
 		const DWORD attr = ::GetFileAttributesW(filePath.AsInternal());
@@ -55,13 +55,13 @@ void SciTEWin::SetFileProperties(
 	}
 
 	::GetDateFormatA(LOCALE_USER_DEFAULT,
-	                DATE_SHORTDATE, NULL,     	// Current date
-	                NULL, temp, TEMP_LEN);
+			 DATE_SHORTDATE, nullptr,     	// Current date
+			 nullptr, temp, TEMP_LEN);
 	ps.Set("CurrentDate", temp);
 
 	::GetTimeFormatA(LOCALE_USER_DEFAULT,
-	                0, NULL,     	// Current time
-	                NULL, temp, TEMP_LEN);
+			 0, nullptr,     	// Current time
+			 nullptr, temp, TEMP_LEN);
 	ps.Set("CurrentTime", temp);
 }
 
@@ -71,7 +71,7 @@ void SciTEWin::SetFileProperties(
 void SciTEWin::SetStatusBarText(const char *s) {
 	GUI::gui_string barText = GUI::StringFromUTF8(s);
 	::SendMessage(HwndOf(wStatusBar),
-	              SB_SETTEXT, 0, reinterpret_cast<LPARAM>(barText.c_str()));
+		      SB_SETTEXT, 0, reinterpret_cast<LPARAM>(barText.c_str()));
 }
 
 void SciTEWin::TabInsert(int index, const GUI::gui_char *title) {
@@ -91,13 +91,13 @@ void SciTEWin::RemoveAllTabs() {
 	TabCtrl_DeleteAllItems(HwndOf(wTabBar));
 }
 
-GUI::Point PointOfCursor() {
+GUI::Point PointOfCursor() noexcept {
 	POINT ptCursor;
 	::GetCursorPos(&ptCursor);
 	return GUI::Point(ptCursor.x, ptCursor.y);
 }
 
-GUI::Point ClientFromScreen(HWND hWnd, GUI::Point ptScreen) {
+GUI::Point ClientFromScreen(HWND hWnd, GUI::Point ptScreen) noexcept {
 	POINT ptClient = { ptScreen.x, ptScreen.y };
 	::ScreenToClient(hWnd, &ptClient);
 	return GUI::Point(ptClient.x, ptClient.y);
@@ -105,7 +105,7 @@ GUI::Point ClientFromScreen(HWND hWnd, GUI::Point ptScreen) {
 
 namespace {
 
-int TabAtPoint(HWND hWnd, GUI::Point pt) {
+int TabAtPoint(HWND hWnd, GUI::Point pt) noexcept {
 	TCHITTESTINFO thti;
 	thti.pt.x = pt.x;
 	thti.pt.y = pt.y;
@@ -274,13 +274,13 @@ void SciTEWin::Notify(SCNotification *notification) {
 
 	case SCN_CHARADDED:
 		if ((notification->nmhdr.idFrom == IDM_RUNWIN) &&
-		        jobQueue.IsExecuting() &&
-		        hWriteSubProcess) {
+				jobQueue.IsExecuting() &&
+				hWriteSubProcess) {
 			const char chToWrite = static_cast<char>(notification->ch);
 			if (chToWrite != '\r') {
 				DWORD bytesWrote = 0;
 				::WriteFile(hWriteSubProcess, &chToWrite,
-				            1, &bytesWrote, NULL);
+					    1, &bytesWrote, nullptr);
 			}
 		} else {
 			SciTEBase::Notify(notification);
@@ -289,7 +289,7 @@ void SciTEWin::Notify(SCNotification *notification) {
 
 	case SCN_FOCUSIN:
 		if ((notification->nmhdr.idFrom == IDM_SRCWIN) ||
-			(notification->nmhdr.idFrom == IDM_RUNWIN))
+				(notification->nmhdr.idFrom == IDM_RUNWIN))
 			wFocus = static_cast<HWND>(notification->nmhdr.hwndFrom);
 		SciTEBase::Notify(notification);
 		break;
@@ -323,7 +323,7 @@ void SciTEWin::TimerStart(int mask) {
 	if (timerMask != maskNew) {
 		if (timerMask == 0) {
 			// Create a 1 second ticker
-			::SetTimer(HwndOf(wSciTE), tickerID, 1000, NULL);
+			::SetTimer(HwndOf(wSciTE), tickerID, 1000, nullptr);
 		}
 		timerMask = maskNew;
 	}
@@ -375,15 +375,15 @@ void SciTEWin::SizeSubWindows() {
 
 	if (tabVisible) {	// ? hide one tab only
 		showTab = tabHideOne ?
-		          TabCtrl_GetItemCount(HwndOf(wTabBar)) > 1 :
-		          true;
+			  TabCtrl_GetItemCount(HwndOf(wTabBar)) > 1 :
+			  true;
 	}
 
 	bands[bandTab].visible = showTab;
 	if (showTab && tabMultiLine) {
 		wTabBar.SetPosition(GUI::Rectangle(
-			rcClient.left, rcClient.top + visHeightTools,
-			rcClient.right, rcClient.top + heightTab + visHeightTools));
+					    rcClient.left, rcClient.top + visHeightTools,
+					    rcClient.right, rcClient.top + heightTab + visHeightTools));
 	}
 
 	RECT r = { rcClient.left, 0, rcClient.right, 0 };
@@ -411,7 +411,7 @@ void SciTEWin::SizeSubWindows() {
 	}
 	if (heightContent <= 0) {
 		heightContent = rcClient.Height();
-		for (size_t i=0;i<bands.size();i++) {
+		for (size_t i=0; i<bands.size(); i++) {
 			if (i != bandContents)
 				bands[i].visible = false;
 		}
@@ -428,15 +428,15 @@ void SciTEWin::SizeSubWindows() {
 			const GUI::Rectangle rcToSet(rcClient.left, yPos, rcClient.right, yPos + band.height);
 			if (hdwp)
 				hdwp = ::DeferWindowPos(hdwp, HwndOf(band.win),
-				0, rcToSet.left, rcToSet.top, rcToSet.Width(), rcToSet.Height(),
-				SWP_NOZORDER|SWP_NOACTIVATE|SWP_SHOWWINDOW);
+							0, rcToSet.left, rcToSet.top, rcToSet.Width(), rcToSet.Height(),
+							SWP_NOZORDER|SWP_NOACTIVATE|SWP_SHOWWINDOW);
 			yPos += band.height;
 		} else {
 			const GUI::Rectangle rcToSet(rcClient.left, rcClient.top - 41, rcClient.Width(), rcClient.top - 40);
 			if (hdwp)
 				hdwp = ::DeferWindowPos(hdwp, HwndOf(band.win),
-				0, rcToSet.left, rcToSet.top, rcToSet.Width(), rcToSet.Height(),
-				SWP_NOZORDER|SWP_NOACTIVATE|SWP_HIDEWINDOW);
+							0, rcToSet.left, rcToSet.top, rcToSet.Width(), rcToSet.Height(),
+							SWP_NOZORDER|SWP_NOACTIVATE|SWP_HIDEWINDOW);
 		}
 	}
 	if (hdwp)
@@ -458,7 +458,7 @@ void SciTEWin::SizeSubWindows() {
 
 
 void SciTEWin::SetMenuItem(int menuNumber, int position, int itemID,
-                           const GUI::gui_char *text, const GUI::gui_char *mnemonic) {
+			   const GUI::gui_char *text, const GUI::gui_char *mnemonic) {
 	// On Windows the menu items are modified if they already exist or are created
 	HMENU hmenu = ::GetSubMenu(::GetMenu(MainHWND()), menuNumber);
 	GUI::gui_string sTextMnemonic = text;
@@ -516,10 +516,10 @@ void SciTEWin::CheckAMenuItem(int wIDCheckItem, bool val) {
 		CheckMenuItem(::GetMenu(MainHWND()), wIDCheckItem, MF_UNCHECKED | MF_BYCOMMAND);
 }
 
-void EnableButton(HWND wTools, int id, bool enable) {
+void EnableButton(HWND wTools, int id, bool enable) noexcept {
 	if (wTools) {
 		::SendMessage(wTools, TB_ENABLEBUTTON, id,
-	              LongFromTwoShorts(static_cast<short>(enable ? TRUE : FALSE), 0));
+			      IntFromTwoShorts(enable ? TRUE : FALSE, 0));
 	}
 }
 
@@ -534,19 +534,19 @@ void SciTEWin::EnableAMenuItem(int wIDCheckItem, bool val) {
 void SciTEWin::CheckMenus() {
 	SciTEBase::CheckMenus();
 	::CheckMenuRadioItem(::GetMenu(MainHWND()), IDM_EOL_CRLF, IDM_EOL_LF,
-	                   wEditor.Call(SCI_GETEOLMODE) - SC_EOL_CRLF + IDM_EOL_CRLF, 0);
+			     static_cast<int>(wEditor.EOLMode()) - static_cast<int>(SA::EndOfLine::CrLf) + IDM_EOL_CRLF, 0);
 	::CheckMenuRadioItem(::GetMenu(MainHWND()), IDM_ENCODING_DEFAULT, IDM_ENCODING_UCOOKIE,
-	                   CurrentBuffer()->unicodeMode + IDM_ENCODING_DEFAULT, 0);
+			     CurrentBuffer()->unicodeMode + IDM_ENCODING_DEFAULT, 0);
 }
 
 void SciTEWin::LocaliseMenu(HMENU hmenu) {
 	for (int i = 0; i <= ::GetMenuItemCount(hmenu); i++) {
 		GUI::gui_char buff[200];
 		buff[0] = '\0';
-		MENUITEMINFOW mii = MENUITEMINFOW();
+		MENUITEMINFOW mii {};
 		mii.cbSize = sizeof(mii);
 		mii.fMask = MIIM_CHECKMARKS | MIIM_DATA | MIIM_ID |
-		            MIIM_STATE | MIIM_SUBMENU | MIIM_TYPE;
+			    MIIM_STATE | MIIM_SUBMENU | MIIM_TYPE;
 		mii.dwTypeData = buff;
 		mii.cch = sizeof(buff) - 1;
 		if (::GetMenuItemInfoW(hmenu, i, TRUE, &mii)) {
@@ -616,45 +616,45 @@ struct BarButton {
 };
 
 static BarButton bbs[] = {
-    { -1,           0 },
-    { STD_FILENEW,  IDM_NEW },
-    { STD_FILEOPEN, IDM_OPEN },
-    { STD_FILESAVE, IDM_SAVE },
-    { 0,            IDM_CLOSE },
-    { -1,           0 },
-    { STD_PRINT,    IDM_PRINT },
-    { -1,           0 },
-    { STD_CUT,      IDM_CUT },
-    { STD_COPY,     IDM_COPY },
-    { STD_PASTE,    IDM_PASTE },
-    { STD_DELETE,   IDM_CLEAR },
-    { -1,           0 },
-    { STD_UNDO,     IDM_UNDO },
-    { STD_REDOW,    IDM_REDO },
-    { -1,           0 },
-    { STD_FIND,     IDM_FIND },
-    { STD_REPLACE,  IDM_REPLACE },
+	{ -1,           0 },
+	{ STD_FILENEW,  IDM_NEW },
+	{ STD_FILEOPEN, IDM_OPEN },
+	{ STD_FILESAVE, IDM_SAVE },
+	{ 0,            IDM_CLOSE },
+	{ -1,           0 },
+	{ STD_PRINT,    IDM_PRINT },
+	{ -1,           0 },
+	{ STD_CUT,      IDM_CUT },
+	{ STD_COPY,     IDM_COPY },
+	{ STD_PASTE,    IDM_PASTE },
+	{ STD_DELETE,   IDM_CLEAR },
+	{ -1,           0 },
+	{ STD_UNDO,     IDM_UNDO },
+	{ STD_REDOW,    IDM_REDO },
+	{ -1,           0 },
+	{ STD_FIND,     IDM_FIND },
+	{ STD_REPLACE,  IDM_REPLACE },
 };
 
-static WNDPROC stDefaultTabProc = NULL;
+static WNDPROC stDefaultTabProc = nullptr;
 static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM lParam) {
 
-	static BOOL st_bDragBegin = FALSE;
-	static int st_iDraggingTab = -1;
-	static int st_iLastClickTab = -1;
-	static HWND st_hwndLastFocus {};
+	static bool bDragBegin = false;
+	static int iDraggingTab = -1;
+	static int iLastClickTab = -1;
+	static HWND hwndLastFocus {};
 
 	switch (iMessage) {
 
 	case WM_LBUTTONDOWN: {
 			const GUI::Point pt = PointFromLong(lParam);
-			st_iLastClickTab = TabAtPoint(hWnd, pt);
+			iLastClickTab = TabAtPoint(hWnd, pt);
 		}
 		break;
 	}
 
 	LRESULT retResult;
-	if (stDefaultTabProc != NULL) {
+	if (stDefaultTabProc != nullptr) {
 		retResult = CallWindowProc(stDefaultTabProc, hWnd, iMessage, wParam, lParam);
 	} else {
 		retResult = ::DefWindowProc(hWnd, iMessage, wParam, lParam);
@@ -673,35 +673,35 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 		break;
 
 	case WM_LBUTTONUP: {
-			st_iLastClickTab = -1;
-			if (st_bDragBegin == TRUE) {
-				if (st_hwndLastFocus) ::SetFocus(st_hwndLastFocus);
+			iLastClickTab = -1;
+			if (bDragBegin) {
+				if (hwndLastFocus) ::SetFocus(hwndLastFocus);
 				::ReleaseCapture();
 				::SetCursor(::LoadCursor(NULL, IDC_ARROW));
-				st_bDragBegin = FALSE;
+				bDragBegin = false;
 				const GUI::Point pt = PointFromLong(lParam);
 				const int tab = TabAtPoint(hWnd, pt);
-				if (tab > -1 && st_iDraggingTab > -1 && st_iDraggingTab != tab) {
+				if (tab > -1 && iDraggingTab > -1 && iDraggingTab != tab) {
 					::SendMessage(::GetParent(hWnd),
-					        WM_COMMAND,
-					        IDC_SHIFTTAB,
-					        MAKELPARAM(st_iDraggingTab, tab));
+						      WM_COMMAND,
+						      IDC_SHIFTTAB,
+						      MAKELPARAM(iDraggingTab, tab));
 				}
-				st_iDraggingTab = -1;
+				iDraggingTab = -1;
 			}
 		}
 		break;
 
 	case WM_KEYDOWN: {
 			if (wParam == VK_ESCAPE) {
-				if (st_bDragBegin == TRUE) {
-					if (st_hwndLastFocus) ::SetFocus(st_hwndLastFocus);
+				if (bDragBegin) {
+					if (hwndLastFocus) ::SetFocus(hwndLastFocus);
 					::ReleaseCapture();
 					::SetCursor(::LoadCursor(NULL, IDC_ARROW));
-					st_bDragBegin = FALSE;
-					st_iDraggingTab = -1;
-					st_iLastClickTab = -1;
-					::InvalidateRect(hWnd, NULL, FALSE);
+					bDragBegin = false;
+					iDraggingTab = -1;
+					iLastClickTab = -1;
+					::InvalidateRect(hWnd, nullptr, FALSE);
 				}
 			}
 		}
@@ -714,22 +714,22 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 			const int tabcount = TabCtrl_GetItemCount(hWnd);
 
 			if (wParam == MK_LBUTTON &&
-			        tabcount > 1 &&
-			        tab > -1 &&
-			        st_iLastClickTab == tab &&
-			        st_bDragBegin == FALSE) {
-				st_iDraggingTab = tab;
+					tabcount > 1 &&
+					tab > -1 &&
+					iLastClickTab == tab &&
+					!bDragBegin) {
+				iDraggingTab = tab;
 				::SetCapture(hWnd);
-				st_hwndLastFocus = ::SetFocus(hWnd);
-				st_bDragBegin = TRUE;
+				hwndLastFocus = ::SetFocus(hWnd);
+				bDragBegin = true;
 				HCURSOR hcursor = ::LoadCursor(::GetModuleHandle(NULL),
-				        MAKEINTRESOURCE(IDC_DRAGDROP));
+							       MAKEINTRESOURCE(IDC_DRAGDROP));
 				if (hcursor) ::SetCursor(hcursor);
 			} else {
-				if (st_bDragBegin == TRUE) {
-					if (tab > -1 && st_iDraggingTab > -1 /*&& st_iDraggingTab != tab*/) {
+				if (bDragBegin) {
+					if (tab > -1 && iDraggingTab > -1 /*&& iDraggingTab != tab*/) {
 						HCURSOR hcursor = ::LoadCursor(::GetModuleHandle(NULL),
-						        MAKEINTRESOURCE(IDC_DRAGDROP));
+									       MAKEINTRESOURCE(IDC_DRAGDROP));
 						if (hcursor) ::SetCursor(hcursor);
 					} else {
 						::SetCursor(::LoadCursor(NULL, IDC_NO));
@@ -740,21 +740,21 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 		break;
 
 	case WM_PAINT: {
-			if (st_bDragBegin == TRUE && st_iDraggingTab != -1) {
+			if (bDragBegin && iDraggingTab != -1) {
 
 				const GUI::Point ptClient = ClientFromScreen(hWnd, PointOfCursor());
 				const int tab = TabAtPoint(hWnd, ptClient);
 
 				RECT tabrc;
 				if (tab != -1 &&
-				        tab != st_iDraggingTab &&
-				        TabCtrl_GetItemRect(hWnd, tab, &tabrc)) {
+						tab != iDraggingTab &&
+						TabCtrl_GetItemRect(hWnd, tab, &tabrc)) {
 
 					HDC hDC = ::GetDC(hWnd);
 					if (hDC) {
 
-						int xLeft = tabrc.left + 8;
-						int yLeft = tabrc.top + (tabrc.bottom - tabrc.top) / 2;
+						const int xLeft = tabrc.left + 8;
+						const int yLeft = tabrc.top + (tabrc.bottom - tabrc.top) / 2;
 						POINT ptsLeftArrow[] = {
 							{xLeft, yLeft - 2},
 							{xLeft - 2, yLeft - 2},
@@ -765,8 +765,8 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 							{xLeft, yLeft + 2}
 						};
 
-						int xRight = tabrc.right - 10;
-						int yRight = tabrc.top + (tabrc.bottom - tabrc.top) / 2;
+						const int xRight = tabrc.right - 10;
+						const int yRight = tabrc.top + (tabrc.bottom - tabrc.top) / 2;
 						POINT ptsRightArrow[] = {
 							{xRight, yRight - 2},
 							{xRight + 2, yRight - 2},
@@ -777,12 +777,12 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 							{xRight, yRight + 2}
 						};
 
-						HPEN pen = ::CreatePen(0,1,RGB(255, 0, 0));
+						HPEN pen = ::CreatePen(0, 1, RGB(255, 0, 0));
 						HPEN penOld = SelectPen(hDC, pen);
 						const COLORREF colourNearest = ::GetNearestColor(hDC, RGB(255, 0, 0));
 						HBRUSH brush = ::CreateSolidBrush(colourNearest);
 						HBRUSH brushOld = SelectBrush(hDC, brush);
-						::Polygon(hDC, tab < st_iDraggingTab ? ptsLeftArrow : ptsRightArrow, 7);
+						::Polygon(hDC, tab < iDraggingTab ? ptsLeftArrow : ptsRightArrow, 7);
 						SelectBrush(hDC, brushOld);
 						DeleteBrush(brush);
 						SelectPen(hDC, penOld);
@@ -804,76 +804,76 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 void SciTEWin::Creation() {
 
 	wContent = ::CreateWindowEx(
-	               flatterUI ? 0 : WS_EX_CLIENTEDGE,
-	               classNameInternal,
-	               TEXT("Source"),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	               0, 0,
-	               100, 100,
-	               MainHWND(),
-	               HmenuID(2000),
-	               hInstance,
-	               &contents);
+			   flatterUI ? 0 : WS_EX_CLIENTEDGE,
+			   classNameInternal,
+			   TEXT("Source"),
+			   WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+			   0, 0,
+			   100, 100,
+			   MainHWND(),
+			   HmenuID(2000),
+			   hInstance,
+			   &contents);
 	wContent.Show();
 
 	wEditor.SetScintilla(::CreateWindowEx(
-	              0,
-	              TEXT("Scintilla"),
-	              TEXT("Source"),
-	              WS_CHILD | WS_VSCROLL | WS_HSCROLL | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	              0, 0,
-	              100, 100,
-	              HwndOf(wContent),
-	              HmenuID(IDM_SRCWIN),
-	              hInstance,
-	              0));
+				     0,
+				     TEXT("Scintilla"),
+				     TEXT("Source"),
+				     WS_CHILD | WS_VSCROLL | WS_HSCROLL | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+				     0, 0,
+				     100, 100,
+				     HwndOf(wContent),
+				     HmenuID(IDM_SRCWIN),
+				     hInstance,
+				     0));
 	if (!wEditor.CanCall())
 		exit(FALSE);
 	wEditor.Show();
-	wEditor.Call(SCI_USEPOPUP, 0);
-	wEditor.Call(SCI_SETCOMMANDEVENTS, 0);
+	wEditor.UsePopUp(SA::PopUp::Never);
+	wEditor.SetCommandEvents(false);
 	WindowSetFocus(wEditor);
 
 	wOutput.SetScintilla(::CreateWindowEx(
-	              0,
-	              TEXT("Scintilla"),
-	              TEXT("Run"),
-	              WS_CHILD | WS_VSCROLL | WS_HSCROLL | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	              0, 0,
-	              100, 100,
-	              HwndOf(wContent),
-	              HmenuID(IDM_RUNWIN),
-	              hInstance,
-	              0));
+				     0,
+				     TEXT("Scintilla"),
+				     TEXT("Run"),
+				     WS_CHILD | WS_VSCROLL | WS_HSCROLL | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+				     0, 0,
+				     100, 100,
+				     HwndOf(wContent),
+				     HmenuID(IDM_RUNWIN),
+				     hInstance,
+				     0));
 	if (!wOutput.CanCall())
 		exit(FALSE);
 	wOutput.Show();
-	wOutput.Call(SCI_SETCOMMANDEVENTS, 0);
+	wOutput.SetCommandEvents(false);
 	// No selection margin on output window
-	wOutput.Call(SCI_SETMARGINWIDTHN, 1, 0);
-	//wOutput.Call(SCI_SETCARETPERIOD, 0);
-	wOutput.Call(SCI_USEPOPUP, 0);
+	wOutput.SetMarginWidthN(1, 0);
+	//wOutput.SetCaretPeriod(0);
+	wOutput.UsePopUp(SA::PopUp::Never);
 	::DragAcceptFiles(MainHWND(), true);
 
 	HWND hwndToolBar = ::CreateWindowEx(
-	               0,
-	               TOOLBARCLASSNAME,
-	               TEXT(""),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS |
-	               TBSTYLE_FLAT | TBSTYLE_TOOLTIPS | CCS_NORESIZE,
-	               0, 0,
-	               100, tbLarge ? heightToolsBig : heightTools,
-	               MainHWND(),
-	               HmenuID(IDM_TOOLWIN),
-	               hInstance,
-	               0);
+				   0,
+				   TOOLBARCLASSNAME,
+				   TEXT(""),
+				   WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS |
+				   TBSTYLE_FLAT | TBSTYLE_TOOLTIPS | CCS_NORESIZE,
+				   0, 0,
+				   100, tbLarge ? heightToolsBig : heightTools,
+				   MainHWND(),
+				   HmenuID(IDM_TOOLWIN),
+				   hInstance,
+				   0);
 	wToolBar = hwndToolBar;
 
 	::SendMessage(hwndToolBar, TB_BUTTONSTRUCTSIZE, sizeof(TBBUTTON), 0);
 	::SendMessage(hwndToolBar, TB_SETBITMAPSIZE, 0, tbLarge ? MAKELPARAM(24, 24) : MAKELPARAM(16, 16));
 	::SendMessage(hwndToolBar, TB_LOADIMAGES,
-	              tbLarge ? IDB_STD_LARGE_COLOR : IDB_STD_SMALL_COLOR,
-	              reinterpret_cast<LPARAM>(HINST_COMMCTRL));
+		      tbLarge ? IDB_STD_LARGE_COLOR : IDB_STD_SMALL_COLOR,
+		      reinterpret_cast<LPARAM>(HINST_COMMCTRL));
 
 	TBADDBITMAP addbmp = { hInstance, IDR_CLOSEFILE };
 
@@ -883,15 +883,15 @@ void SciTEWin::Creation() {
 
 	::SendMessage(hwndToolBar, TB_ADDBITMAP, 1, reinterpret_cast<LPARAM>(&addbmp));
 
-	TBBUTTON tbb[std::size(bbs)];
-	for (unsigned int i = 0;i < std::size(bbs);i++) {
+	TBBUTTON tbb[std::size(bbs)] = {};
+	for (unsigned int i = 0; i < std::size(bbs); i++) {
 		if (bbs[i].cmd == IDM_CLOSE)
 			tbb[i].iBitmap = STD_PRINT + 1;
 		else
 			tbb[i].iBitmap = bbs[i].id;
 		tbb[i].idCommand = bbs[i].cmd;
 		tbb[i].fsState = TBSTATE_ENABLED;
-		if ( -1 == bbs[i].id)
+		if (-1 == bbs[i].id)
 			tbb[i].fsStyle = TBSTYLE_SEP;
 		else
 			tbb[i].fsStyle = TBSTYLE_BUTTON;
@@ -908,7 +908,7 @@ void SciTEWin::Creation() {
 	icce.dwICC = ICC_TAB_CLASSES;
 	InitCommonControlsEx(&icce);
 
-	WNDCLASS wndClass = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
+	WNDCLASS wndClass = {};
 	if (::GetClassInfo(NULL, WC_TABCONTROL, &wndClass) == 0)
 		exit(FALSE);
 	stDefaultTabProc = wndClass.lpfnWndProc;
@@ -920,24 +920,24 @@ void SciTEWin::Creation() {
 		exit(FALSE);
 
 	wTabBar = ::CreateWindowEx(
-	              0,
-	              TEXT("SciTeTabCtrl"),
-	              TEXT("Tab"),
-	              WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS |
-	              TCS_FOCUSNEVER | TCS_TOOLTIPS,
-	              0, 0,
-	              100, heightTab,
-	              MainHWND(),
-	              HmenuID(IDM_TABWIN),
-	              hInstance,
-	              0);
+			  0,
+			  TEXT("SciTeTabCtrl"),
+			  TEXT("Tab"),
+			  WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS |
+			  TCS_FOCUSNEVER | TCS_TOOLTIPS,
+			  0, 0,
+			  100, heightTab,
+			  MainHWND(),
+			  HmenuID(IDM_TABWIN),
+			  hInstance,
+			  0);
 
 	if (!wTabBar.Created())
 		exit(FALSE);
 
 	LOGFONT lfIconTitle;
 	ZeroMemory(&lfIconTitle, sizeof(lfIconTitle));
-	if (::SystemParametersInfo(SPI_GETICONTITLELOGFONT,sizeof(lfIconTitle),&lfIconTitle,FALSE) == 0)
+	if (::SystemParametersInfo(SPI_GETICONTITLELOGFONT, sizeof(lfIconTitle), &lfIconTitle, FALSE) == 0)
 		exit(FALSE);
 	fontTabs = ::CreateFontIndirect(&lfIconTitle);
 	SetWindowFont(HwndOf(wTabBar), fontTabs, 0);
@@ -945,93 +945,93 @@ void SciTEWin::Creation() {
 	wTabBar.Show();
 
 	HWND hwnd = ::CreateWindowEx(
-	               0,
-	               classNameInternal,
-	               TEXT("userStrip"),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	               0, 0,
-	               100, 100,
-	               MainHWND(),
-	               HmenuID(2001),
-	               hInstance,
-	               &userStrip);
+			    0,
+			    classNameInternal,
+			    TEXT("userStrip"),
+			    WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+			    0, 0,
+			    100, 100,
+			    MainHWND(),
+			    HmenuID(2001),
+			    hInstance,
+			    &userStrip);
 	if (!hwnd)
 		exit(FALSE);
 
 	hwnd = ::CreateWindowEx(
-	               0,
-	               classNameInternal,
-	               TEXT("backgroundStrip"),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	               0, 0,
-	               100, 100,
-	               MainHWND(),
-	               HmenuID(2001),
-	               hInstance,
-	               &backgroundStrip);
+		       0,
+		       classNameInternal,
+		       TEXT("backgroundStrip"),
+		       WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+		       0, 0,
+		       100, 100,
+		       MainHWND(),
+		       HmenuID(2001),
+		       hInstance,
+		       &backgroundStrip);
 	if (!hwnd)
 		exit(FALSE);
 
 	hwnd = ::CreateWindowEx(
-	               0,
-	               classNameInternal,
-	               TEXT("searchStrip"),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	               0, 0,
-	               100, 100,
-	               MainHWND(),
-	               HmenuID(2001),
-	               hInstance,
-	               &searchStrip);
+		       0,
+		       classNameInternal,
+		       TEXT("searchStrip"),
+		       WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+		       0, 0,
+		       100, 100,
+		       MainHWND(),
+		       HmenuID(2001),
+		       hInstance,
+		       &searchStrip);
 	if (!hwnd)
 		exit(FALSE);
 
 	hwnd = ::CreateWindowEx(
-	               0,
-	               classNameInternal,
-	               TEXT("FindStrip"),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	               0, 0,
-	               100, 100,
-	               MainHWND(),
-	               HmenuID(2002),
-	               hInstance,
-	               &findStrip);
+		       0,
+		       classNameInternal,
+		       TEXT("FindStrip"),
+		       WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+		       0, 0,
+		       100, 100,
+		       MainHWND(),
+		       HmenuID(2002),
+		       hInstance,
+		       &findStrip);
 	if (!hwnd)
 		exit(FALSE);
 
 	hwnd = ::CreateWindowEx(
-	               0,
-	               classNameInternal,
-	               TEXT("ReplaceStrip"),
-	               WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
-	               0, 0,
-	               100, 100,
-	               MainHWND(),
-	               HmenuID(2003),
-	               hInstance,
-	               &replaceStrip);
+		       0,
+		       classNameInternal,
+		       TEXT("ReplaceStrip"),
+		       WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
+		       0, 0,
+		       100, 100,
+		       MainHWND(),
+		       HmenuID(2003),
+		       hInstance,
+		       &replaceStrip);
 	if (!hwnd)
 		exit(FALSE);
 
 	wStatusBar = ::CreateWindowEx(
-	                 0,
-	                 STATUSCLASSNAME,
-	                 TEXT(""),
-	                 WS_CHILD | WS_CLIPSIBLINGS,
-	                 0, 0,
-	                 100, heightStatus,
-	                 MainHWND(),
-	                 HmenuID(IDM_STATUSWIN),
-	                 hInstance,
-	                 0);
+			     0,
+			     STATUSCLASSNAME,
+			     TEXT(""),
+			     WS_CHILD | WS_CLIPSIBLINGS,
+			     0, 0,
+			     100, heightStatus,
+			     MainHWND(),
+			     HmenuID(IDM_STATUSWIN),
+			     hInstance,
+			     0);
 	wStatusBar.Show();
 	const int widths[] = { 4000 };
 	// Perhaps we can define a syntax to create more parts,
 	// but it is probably an overkill for a marginal feature
 	::SendMessage(HwndOf(wStatusBar),
-	              SB_SETPARTS, 1,
-	              reinterpret_cast<LPARAM>(widths));
+		      SB_SETPARTS, 1,
+		      reinterpret_cast<LPARAM>(widths));
 
 	bands.push_back(Band(true, tbLarge ? heightToolsBig : heightTools, false, wToolBar));
 	bands.push_back(Band(true, heightTab, false, wTabBar));
@@ -1044,9 +1044,9 @@ void SciTEWin::Creation() {
 	bands.push_back(Band(true, heightStatus, false, wStatusBar));
 
 #ifndef NO_LUA
-		if (props.GetExpandedString("ext.lua.startup.script").length() == 0)
-			DestroyMenuItem(menuOptions,IDM_OPENLUAEXTERNALFILE);
+	if (props.GetExpandedString("ext.lua.startup.script").length() == 0)
+		DestroyMenuItem(menuOptions, IDM_OPENLUAEXTERNALFILE);
 #else
-		DestroyMenuItem(menuOptions,IDM_OPENLUAEXTERNALFILE);
+	DestroyMenuItem(menuOptions, IDM_OPENLUAEXTERNALFILE);
 #endif
 }
